@@ -12,7 +12,7 @@ from tools.config.save import save
 #
 # Exported variables (internal configuration)
 #
-version = "1.4.2"
+version = "1.5.0"
 tools_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 
 # Keys saved in the config file (mostly what we ask in 'waydroid init')
@@ -22,7 +22,8 @@ config_keys = ["arch",
                "system_datetime",
                "vendor_datetime",
                "suspend_action",
-               "mount_overlays"]
+               "mount_overlays",
+               "auto_adb"]
 
 # Config file/commandline default values
 # $WORK gets replaced with the actual value for args.work (which may be
@@ -39,6 +40,9 @@ defaults = {
     ],
     "suspend_action": "freeze",
     "mount_overlays": "True",
+    "auto_adb": "True",
+    "container_xdg_runtime_dir": "/run/xdg",
+    "container_wayland_display": "wayland-0",
 }
 defaults["images_path"] = defaults["work"] + "/images"
 defaults["rootfs"] = defaults["work"] + "/rootfs"
@@ -48,6 +52,7 @@ defaults["overlay_work"] = defaults["work"] + "/overlay_work"
 defaults["data"] = defaults["work"] + "/data"
 defaults["lxc"] = defaults["work"] + "/lxc"
 defaults["host_perms"] = defaults["work"] + "/host-permissions"
+defaults["container_pulse_runtime_path"] = defaults["container_xdg_runtime_dir"] + "/pulse"
 
 session_defaults = {
     "user_name": pwd.getpwuid(os.getuid()).pw_name,
@@ -63,7 +68,6 @@ session_defaults = {
     "lcd_density": "0",
     "background_start": "true"
 }
-session_defaults["config_path"] = defaults["work"] + "/session.cfg"
 session_defaults["waydroid_data"] = session_defaults["xdg_data_home"] + \
     "/waydroid/data"
 if session_defaults["pulse_runtime_path"] == "None":
